/*


This do file replicates the simulation presented in figure 1 of the paper. The 
seed is set at the beginning of this replication. 


Set the working directory to the Replication flies folder
e.g.  cd "C:\Users\Amanda\Dropbox\Lying about poverty\Replication files"
*/


*************************************************************************************************

*Code for new program that estimates effects of actual and (mis)reported incomes on vote choice 

*program drop bias_gov
clear
set more off
set seed 0000

program define bias_gov, rclass

clear

set obs 5000
generate beta = 0.2
generate cost_seed = runiform()
generate threshold = 0.3
generate seed = runiform()
generate gov_seed = 0

*sets likelihood of government sponsor
scalar gov_probability  = runiform()
*sets effective tax rate
scalar efftax = runiform()

*sets "government sponsor" at zero or one
generate gov_prob = gov_probability
summarize gov_prob
return scalar gov_prob = r(mean)
generate gov = 0
replace gov = 1 if gov_seed<gov_prob

*returns effective tax rate
generate effective = efftax
summarize effective 
return scalar eff = r(mean)

*generates actual and reported income
generate income = runiform() 
generate cost = cost_seed * (income - 0.3)
generate income_bias = income
generate mu = effective*(income -.3)
replace income_bias = runiform(0,.3) if mu>cost & gov==1

*generates voting preference based on actual income
generate vote_prob =  1/(1 + exp(-(beta*(income))))
generate vote = 0
replace vote = 1 if vote_prob>seed

*estimates effect of actual income 
logit vote income 
return scalar true = _b[income] 

*estimates effect from reported income
logit vote income_bias 
return scalar bias = _b[income_bias] 

generate inter = income_bias * gov
logit vote income_bias gov inter
return scalar inter = _b[income_bias] 

end

*code for running simulation and creating figure

simulate true=r(true) bias=r(bias) gov=r(gov_prob) eff=r(eff) inter=r(inter), reps(1000):bias_gov
generate deviation = bias - true

twoway(kdensity true)(kdensity bias if eff<0.15,lpattern(dash))(kdensity bias if eff>0.15,lpattern(shortdash_dot)), ///
			scheme(s2mono) graphregion(fcolor(white) ilcolor(white) lcolor(white)) ///
			ylabel( ,nogrid) ///
			legend(off) ///
			xtitle("Impact of Income on Vote Choice") ///
			ytitle("Density") ///
			text(3 .47 "Estimated beta" "with no misreporting", size(small)) ///
			text(4.4 .38 "Estimated beta" "if tax rate <15%", size(small)) ///
			text(2 -.2 "Estimated beta" "if tax rate>15%", size(small))

graph save Graph "figures\simulation_tax", replace
