/*


This do file replicates the analysis for all of the primary tables and figures
in the paper.

Code used to generate simulations included in the simulate.do file


NOTE: The tables created by the estout are not perfectly formatted. The format 
of these tables was slightly altered in the paper, although the results are the 
same
*/

*************************************************************************************************
** Install dependency

ssc install estout, replace // this helps with outputting the results


******************************************************************************
** Run the do files that clean and recode the Afrobarometer dataset
*Or use the cleaned data already included in the replication data 

*************************************************************************************************
** Set the working directory to the Replication flies folder
*e.g.  cd "C:\Users\Amanda\Dropbox\Lying about poverty\Replication files"



*************************************************************************************************


*Table 1 & A.7  - round4
use "AB_round4_clean.dta", clear
set more off
eststo clear
eststo: mixed pastperson govspons education electricity paved water age gender survsus difficul survint rural others radionews GDPpc privatetap effective sponsprivate || site:||enum_code:
eststo: mixed pastperson govspons education electricity paved water age gender survsus difficul survint rural others radionews GDPpc effective effectspons if privatetap==0|| site:||enum_code:
eststo: mixed pastperson govspons education electricity paved water age gender survsus difficul survint rural others radionews GDPpc effective effectspons if privatetap==1|| site:||enum_code:
esttab using "tables\main_round4.tex", se legend replace

*Table 2 & A.8- round 5
use "AB_round5_clean.dta", clear
set more off
eststo clear
eststo: mixed pastperson govspons education electricity paved water age gender survsus difficult survint rural others GDPpc radionews privatetap evasiontax sponsprivate if askedtaxes==1|| site:||enum_code:
eststo: mixed pastperson govspons education electricity paved water age gender survsus difficult survint rural others GDPpc radionews evasiontax evasiontaxspons if privatetap==0|| site:||enum_code:
eststo: mixed pastperson govspons education electricity paved water age gender survsus difficult survint rural others GDPpc radionews evasiontax evasiontaxspons if privatetap==1|| site:||enum_code:
esttab using "tables\main_round5.tex", se legend replace
 
*Table 3 & A.9 
eststo clear
use "AB_round4_clean.dta", clear
xtset country
eststo: xtlogit incumbentvote pastperson countryecon pastcountry coethnic rural age gender education govspons privatetap electricity water survsus difficult survint others GDPpc
eststo: xtlogit incumbentvote pastperson countryecon pastcountry coethnic rural age gender education govspons privatetap electricity water survsus difficult survint others GDPpc pastspons 
use "AB_round5_clean.dta", clear
xtset country 
eststo: xtlogit incumbentvote pastperson countryecon pastcountry coethnic rural age gender education govspons privatetap electricity water survsus difficult survint others GDPpc if askedtaxes==1
eststo: xtlogit incumbentvote pastperson countryecon pastcountry coethnic rural age gender education govspons privatetap electricity water survsus difficult survint others GDPpc pastspons if askedtaxes==1
esttab using "tables\incumbent.tex", se legend replace


*Appendix A.5 
*Data copied into a table by hand

use "AB_round4_clean.dta", clear
ttest age, by(govspons)
ttest education, by(govspons)
prtest rural, by(govspons)
prtest female, by(govspons)
ttest radionews, by(govspons)

ttest survsus, by(govspons)
ttest difficult, by(govspons)
ttest survint, by(govspons)
prtest others, by(govspons)

prtest privatetap, by(govspons)
prtest electricity, by(govspons)
ttest GDPpc, by(govspons)
ttest maxtax, by(govspons)


use "AB_round5_clean.dta", clear
ttest age, by(govspons)
ttest education, by(govspons)
prtest rural, by(govspons)
prtest female, by(govspons)
ttest radionews, by(govspons)

ttest survsus, by(govspons)
ttest difficult, by(govspons)
ttest survint, by(govspons)
prtest others, by(govspons)


prtest privatetap, by(govspons)
prtest electricity, by(govspons)
ttest GDPpc, by(govspons)
ttest maxtax, by(govspons)



*Appendix table A.6 (correlates of private tap)
eststo clear
use "AB_round4_clean.dta", clear
xtset country
eststo: xtlogit privatetap electricity paved water age gender employed evernewspaper dailycomputer rural 
use "AB_round5_clean.dta", clear
xtset country
eststo: xtlogit privatetap electricity paved water age gender employed evernewspaper dailycomputer rural  if askedtax==1 
esttab using "tables\privatetap.tex", se legend replace

*Appendix table A.10 (Conditioning on effective tax rate)
eststo clear
use "AB_round4_clean.dta", clear
xtset country
eststo: xtlogit incumbentvote pastperson countryecon pastcountry coethnic rural age gender education govspons effective privatetap electricity water survsus difficult survint others GDPpc 
eststo: xtlogit incumbentvote pastperson countryecon pastcountry coethnic rural age gender education govspons effective pasttax privatetap electricity water survsus difficult survint others GDPpc 
use "AB_round5_clean.dta", clear
xtset country
eststo: xtlogit incumbentvote pastperson countryecon pastcountry coethnic rural age gender education govspons evasiontax privatetap electricity water survsus difficult survint others GDPpc 
eststo: xtlogit incumbentvote pastperson countryecon pastcountry coethnic rural age gender education govspons evasiontax pasttax privatetap electricity water survsus difficult survint others GDPpc 
esttab using "tables\incumbent_tax.tex", se legend replace



*Figure 2

*Figure 2a

use "AB_round4_clean", clear
gen MVZ=(_n/900)
gen yline=0		

set more off
mixed pastperson govspons effective effectspons education electricity paved water age gender survsus difficul survint rural others radionews GDPpc  if privatetap==0|| site:||enum_code:

matrix b=e(b)
matrix V=e(V)
scalar b1=b[1,1]
scalar b3=b[1,3]
scalar varb1=V[1,1]
scalar varb3=V[3,3]
scalar covb1b3=V[1,3]
scalar list b1 b3 varb1 varb3 covb1b3
gen conbx3=b1+b3*MVZ 
gen consx3=sqrt(varb1+varb3*(MVZ^2)+2*covb1b3*MVZ) 
gen ax3=1.96*consx3
gen upperx3=conbx3+ax3
gen lowerx3=conbx3-ax3

graph twoway ||   line conbx3   MVZ, clpattern(solid) clwidth(medium) clcolor(black) yaxis(1) ///
        ||   line upperx3  MVZ, clpattern(dash) clwidth(thin) clcolor(black) ///
        ||   line lowerx3  MVZ, clpattern(dash) clwidth(thin) clcolor(black) ///
                ||   line yline  MVZ,  clwidth(thin) clcolor(black) clpattern(shortdash) ///
			 scheme(s2mono) graphregion(fcolor(white) ilcolor(white) lcolor(white)) ///
			ylabel( ,nogrid) ///	
			legend(off) ///
			title("Marginal Effects of Gov. Sponsor on Egotropic Evaluations," "Round 4 No Private tap") ///
			xtitle("Effective Tax Rate") ///
			ytitle("Marginal Effect of Gov. Sponsor") 
graph save Graph "figures\model2_margin_round4", replace			
			
set more off
mixed pastperson govspons effective effectspons education electricity paved water age gender survsus difficul survint rural others radionews GDPpc  if privatetap==1|| site:||enum_code:

matrix b=e(b)
matrix V=e(V)
scalar b1=b[1,1]
scalar b3=b[1,3]
scalar varb1=V[1,1]
scalar varb3=V[3,3]
scalar covb1b3=V[1,3]
scalar list b1 b3 varb1 varb3 covb1b3
gen conbx4=b1+b3*MVZ 
gen consx4=sqrt(varb1+varb3*(MVZ^2)+2*covb1b3*MVZ) 
gen ax4=1.96*consx4
gen upperx4=conbx4+ax4
gen lowerx4=conbx4-ax4

graph twoway ||   line conbx4   MVZ, clpattern(solid) clwidth(medium) clcolor(black) yaxis(1) ///
        ||   line upperx4  MVZ, clpattern(dash) clwidth(thin) clcolor(black) ///
        ||   line lowerx4  MVZ, clpattern(dash) clwidth(thin) clcolor(black) ///
            ||   line yline  MVZ,  clwidth(thin) clcolor(black) clpattern(shortdash) ///
			 scheme(s2mono) graphregion(fcolor(white) ilcolor(white) lcolor(white)) ///
			ylabel( ,nogrid) ///		legend(off) ///
			legend(off) ///
			title("Marginal Effects of Gov. Sponsor on Egotropic Evaluations," "Round 4 Private tap") ///
			xtitle("Effective Tax Rate") ///
			ytitle("Marginal Effect of Gov. Sponsor") 
			
graph save Graph "figures\model3_margin_round4", replace		
						

*Figure 2b						
						
use "AB_round5_clean", clear
gen MVZ=(_n/25000)
gen yline=0			
					
set more off
mixed pastperson govspons evasiontax evasiontaxspons education electricity paved water age gender survsus difficult survint rural others GDPpc radionews  if privatetap==0|| site:||enum_code:

matrix b=e(b)
matrix V=e(V)
scalar b1=b[1,1]
scalar b3=b[1,3]
scalar varb1=V[1,1]
scalar varb3=V[3,3]
scalar covb1b3=V[1,3]
scalar list b1 b3 varb1 varb3 covb1b3
gen conbx2=b1+b3*MVZ
gen consx2=sqrt(varb1+varb3*(MVZ^2)+2*covb1b3*MVZ) 
gen ax2=1.96*consx2
gen upperx2=conbx2+ax2
gen lowerx2=conbx2-ax2

graph twoway ||   line conbx2   MVZ, clpattern(solid) clwidth(medium) clcolor(black) yaxis(1) ///
        ||   line upperx2  MVZ, clpattern(dash) clwidth(thin) clcolor(black) ///
        ||   line lowerx2  MVZ, clpattern(dash) clwidth(thin) clcolor(black) ///
        ||   line yline  MVZ,  clwidth(thin) clcolor(black) clpattern(shortdash) ///
			 scheme(s2mono) graphregion(fcolor(white) ilcolor(white) lcolor(white)) ///
			ylabel( ,nogrid) ///
			legend(off) ///
			title("Marginal Effects of Gov. Sponsor on Consumption," "Round 5 No Private tap") ///
			xtitle("Effective Tax Rate") ///
			ytitle("Marginal Effect of Gov. Sponsor") 
graph save Graph "figures\model2_margin_round5", replace	
			
			
set more off
mixed pastperson govspons evasiontax evasiontaxspons education electricity paved water age gender survsus difficult survint rural others GDPpc radionews  if privatetap==1|| site:||enum_code:

matrix b=e(b)
matrix V=e(V)
scalar b1=b[1,1]
scalar b3=b[1,3]
scalar varb1=V[1,1]
scalar varb3=V[3,3]
scalar covb1b3=V[1,3]
scalar list b1 b3 varb1 varb3 covb1b3
gen conbx5=b1+b3*MVZ 
gen consx5=sqrt(varb1+varb3*(MVZ^2)+2*covb1b3*MVZ) 
gen ax5=1.96*consx5
gen upperx5=conbx5+ax5
gen lowerx5=conbx5-ax5

graph twoway ||   line conbx5   MVZ, clpattern(solid) clwidth(medium) clcolor(black) yaxis(1) ///
        ||   line upperx5  MVZ, clpattern(dash) clwidth(thin) clcolor(black) ///
        ||   line lowerx5  MVZ, clpattern(dash) clwidth(thin) clcolor(black) ///
                ||   line yline  MVZ,  clwidth(thin) clcolor(black) clpattern(shortdash) ///
			 scheme(s2mono) graphregion(fcolor(white) ilcolor(white) lcolor(white)) ///
			ylabel( ,nogrid) ///	
			legend(off) ///
			title("Marginal Effects of Gov. Sponsor on Egotropic Evaluations," "Round 5 Private tap") ///
			xtitle("Effective Tax Rate") ///
			ytitle("Marginal Effect of Gov. Sponsor") 
graph save Graph "figures\model3_margin_round5", replace				
