/*

This do file cleans round 4 of the Afrobarometer dataset


NOTE: The Afrobarometer changes its coding scheme relatively frequently. For 
this reason we have provided both the original Afrobarometer data as well as 
a version that has been cleaned using this code
*/

*************************************************************************************************
** Set the working directory to the Replication flies folder
*e.g.  cd "C:\Users\Amanda\Dropbox\Lying about poverty\Replication files"

*************************************************************************************************




set more off

use "AB_round4", clear

*CLEANING AND RENAMING VARIABLES
foreach v of varlist _all {
      capture rename `v' `=lower("`v'")'
   }




*Dependent variable

*Dependent variable
rename q100 sponsor
label var sponsor "Who do you think sent us to do this interview?"

*coding perceived government sponsorship
gen govspons=0
replace govspons=. if sponsor==.
replace govspons=1 if sponsor==1
replace govspons=1 if sponsor==2
replace govspons=1 if sponsor==3
replace govspons=1 if sponsor==4
replace govspons=1 if sponsor==5
replace govspons=1 if sponsor==6
replace govspons=1 if sponsor==7
replace govspons=1 if sponsor==8
replace govspons=1 if sponsor==9
replace govspons=1 if sponsor==10
replace govspons=1 if sponsor==11
replace govspons=1 if sponsor==12
replace govspons=1 if sponsor==13
replace govspons=1 if sponsor==14
replace govspons=1 if sponsor==15
replace govspons=1 if sponsor==16
replace govspons=. if sponsor==-1
replace govspons=. if sponsor>995

*independent variables
rename q6b pastpersonecon
label var pastpersonecon "Q6b own living condition compared to 12 months ago"
recode pastpersonecon 9=. -1=.

gen rural=urbrur
recode rural 2=1 1=0

rename ea_svc_a electricity
recode electricity 9=. -1=.

rename ea_svc_b water
recode water 9=. -1=.

rename q1 age
recode age 998=. 999=. -1=.

gen privatetap=q93a
recode privatetap -1=. 9=. 2=1 3=0
tab privatetap

rename q4a countryecon 
label var countryecon "Q4a present economic condition of the country"
recode countryecon 9=. -1=.

rename q6a pastcountryecon 
label var pastcountryecon " Q6a economic condition of the country compared to 12 months ago"
recode pastcountryecon 9=. -1=.

rename q12a radionews
recode radionews 9=. -1=.

rename q12c newspaper
recode newspaper 9=. -1=.

gen evernewspaper = 0
replace evernewspaper = 1 if newspaper>0
replace evernewspaper = . if newspaper == .

gen dailycomputer = 0
replace dailycomputer = 1 if q88b==4
replace dailycomputer = . if dailycomputer == -1
replace dailycomputer = . if dailycomputer == 9

rename q101 gender
gen female=gender
recode female 2=1 1=0

rename q89 education
recode education 99=. -1=.

rename q108b survinterest
label var survinterest "was the respondent intereted in teh survey"
recode survint -1=.

rename q108e survsus
label var survsus "was the respondent suspicious of the interviewer"
recode survsus -1=.

rename q106 difficult
replace difficult=. if difficult==-1

gen others=0
replace others=. if q104==-1
replace others=1 if q104>=4

gen employed = 0
replace employed = . if q94==-1
replace employed = 1 if q94>=4
replace employed = . if q94==9



*Generate scale of consumption (inverse of lived poverty index)

rename q8a foodlack
rename q8b waterlack
rename q8c medicallack
rename q8d fuellack
rename q8e cashlack

replace foodlack=. if foodlack==-1
replace foodlack=. if foodlack==9
replace waterlack=. if waterlack==-1
replace waterlack=. if waterlack==9
replace medicallack=. if medicallack==-1
replace medicallack=. if medicallack==9
replace fuellack=. if fuellack==-1
replace fuellack=. if fuellack==9
replace cashlack=. if cashlack==-1
replace cashlack=. if cashlack==9

factor foodlack waterlack cashlack medicallack fuellack
rotate
predict flivedpov
gen fwealth=0-flivedpov

*GDP - coded from World Bank

gen GDPpc=.
replace GDPpc=16.4 if country==1
replace GDPpc=123.3 if country==2
replace GDPpc=13.5 if country==3
replace GDPpc=59.3 if country==4
replace GDPpc=29.3 if country==5
replace GDPpc=24.1 if country==6
replace GDPpc=20.1 if country==7
replace GDPpc=6.8 if country==8
replace GDPpc=14.3 if country==9
replace GDPpc=7.3 if country==10
replace GDPpc=15 if country==11
replace GDPpc=8.8 if country==12
replace GDPpc=80.6 if country==13
replace GDPpc=48.8 if country==14
replace GDPpc=21.6 if country==15
replace GDPpc=119 if country==16
replace GDPpc=20.8 if country==17
replace GDPpc=15.3 if country==18
replace GDPpc=30.6 if country==19
replace GDPpc=12.7 if country==20

*Tax variables
*Coded from Deloitte and Schneider et al.

gen shadoweconave=.
label variable shadoweconave "Schneider et al. estimation average from 1999-2007"

replace shadoweconave=49.8 if country==1
replace shadoweconave=32.9 if country==2
replace shadoweconave=40.5 if country==3
replace shadoweconave=35.4 if country==4
replace shadoweconave=40.7 if country==5
replace shadoweconave=33.2 if country==6
replace shadoweconave=30.5 if country==7
replace shadoweconave=44.2 if country==8
replace shadoweconave=40.8 if country==9
replace shadoweconave=41.8 if country==10
replace shadoweconave=40.7 if country==11
replace shadoweconave=39.8 if country==12
replace shadoweconave=30.3 if country==13
replace shadoweconave=56.2 if country==14
replace shadoweconave=43.7 if country==15
replace shadoweconave=27.3 if country==16
replace shadoweconave=56.4 if country==17
replace shadoweconave=42.3 if country==18
replace shadoweconave=47.1 if country==19
replace shadoweconave=61.8 if country==20

gen maxtax=0
replace maxtax=.45 if country==1
replace maxtax=.25 if country==2
replace maxtax=.3 if country==3
replace maxtax=.26 if country==4
replace maxtax=.25 if country==5
replace maxtax=.3 if country==6
replace maxtax=.30 if country==7
replace maxtax=.25 if country==8
replace maxtax=.3 if country==9
replace maxtax=.3 if country==10
replace maxtax=.4 if country==11
replace maxtax=.32 if country==12
replace maxtax=.37 if country==13
replace maxtax=.2 if country==14
replace maxtax=.5 if country==15
replace maxtax=.4 if country==16
replace maxtax=.3 if country==17
replace maxtax=.3 if country==18
replace maxtax=.35 if country==19
replace maxtax=.35 if country==20

gen effective=(maxtax)*(100-shadoweconave)

*Coethnicity with incumbent - coded from EPR database

rename q79 ethnic

gen coethnic=0 
replace coethnic=1 if ethnic==102 
replace coethnic=1 if ethnic==142 
replace coethnic=1 if ethnic==182 
replace coethnic=. if country==4
replace coethnic=1 if ethnic==260 
replace coethnic=1 if ethnic==300 
replace coethnic=1 if ethnic==304 
replace coethnic=1 if ethnic==317
replace coethnic=1 if ethnic==340
replace coethnic=1 if ethnic==392 
replace coethnic=1 if ethnic==432 
replace coethnic=1 if ethnic==466 
replace coethnic=1 if ethnic==464 
replace coethnic=1 if ethnic==467 
replace coethnic=1 if ethnic==509
replace coethnic=1 if ethnic==544 
replace coethnic=1 if ethnic==580 
replace coethnic=1 if ethnic==620 
replace coethnic=1 if ethnic==625 
replace coethnic=1 if ethnic==660 
replace coethnic=1 if ethnic==703 
replace coethnic=1 if ethnic==781
replace coethnic=1 if ethnic==782 
replace coethnic=1 if ethnic==796
replace coethnic=1 if ethnic==822 
replace coethnic=1 if ethnic==821 
replace coethnic=1 if ethnic==820
replace coethnic=1 if ethnic==861
replace coethnic=. if country==7 
replace coethnic=. if country==17
replace coethnic=. if ethnic==-1
replace coethnic=. if ethnic>=220 & ethnic<=230
replace coethnic=. if ethnic>=990


*Incumbent Vote 
rename q97 presvote
gen incumbentvote=0
label var incumbentvote "presvote dummy would the person vote for the current incumbent party if the election was tomorrow?"
recode incumbentvote -1=. 999=. 998=. 997=.

replace incumbentvote=1 if presvote==100
replace incumbentvote=1 if presvote==142
replace incumbentvote=1 if presvote==180
replace incumbentvote=1 if presvote==221
replace incumbentvote=1 if presvote==262
replace incumbentvote=1 if presvote==302
replace incumbentvote=1 if presvote==340
replace incumbentvote=1 if presvote==409
replace incumbentvote=1 if presvote==420
replace incumbentvote=1 if presvote==461
replace incumbentvote=1 if presvote==515
replace incumbentvote=1 if presvote==540
replace incumbentvote=1 if presvote==590
replace incumbentvote=1 if presvote==623
replace incumbentvote=1 if presvote==660
replace incumbentvote=1 if presvote==702
replace incumbentvote=1 if presvote==740
replace incumbentvote=1 if presvote==780
replace incumbentvote=1 if presvote==822
replace incumbentvote=1 if presvote==861

*Generate site codes by identifying EAs that match on all EA-wide dimensions

rename ea_fac_a postoffice
recode postoffice 9=.
rename ea_fac_b nearschool
recode nearschool 9=.
rename ea_svc_c sewage
recode sewage 9=.
rename ea_svc_d cellservice
recode cell 9=. 7=.
rename ea_fac_c nearpolice
recode nearpolice 9=.
rename ea_fac_d nearhealth
recode nearhealth 9=.
rename ea_fac_e nearmarket
recode nearhealth 9=.
rename ea_road paved
recode paved 9=.

egen site=group(district electricity water sewage cellservice postoffice nearschool nearpolice nearhealth nearmarket paved)

*Enumerator codes
rename q110 enum_code

*Interactions

gen sponsprivate=privatetap*govspons
gen effectspons= effective*govspons
gen wealthspons=fwealth*govspons
gen pastspons=pastperson*govspons
gen pasttax=pastperson*effective







