/*

This do file cleans round 5 of the Afrobarometer dataset


NOTE: The Afrobarometer changes its coding scheme relatively frequently. For 
this reason we have provided both the original Afrobarometer data as well as 
a version that has been cleaned using this code
*/

*************************************************************************************************
** Set the working directory to the Replication flies folder
*e.g.  cd "C:\Users\Amanda\Dropbox\Lying about poverty\Replication files"

*************************************************************************************************




set more off

use "AB_round5", clear

*CLEANING AND RENAING VARIABLES
foreach v of varlist _all {
      capture rename `v' `=lower("`v'")'
   }


   
   
   
*Dependent variable
rename q100 sponsor
label var sponsor "Who do you think sent us to do this interview?"
replace sponsor=. if sponsor==-1
replace sponsor=. if sponsor==998
replace sponsor=. if sponsor==999
replace sponsor=. if sponsor==0

*coding perceived government sponsorship
gen govspons=0
replace govspons=. if sponsor==.

*Government (general)      
replace govspons=1 if sponsor==1

*National/ federal government
replace govspons=1 if sponsor==2

*Provincial/ regional government
replace govspons=1 if sponsor==3

*Local government
replace govspons=1 if sponsor==4

*President/PM's office
replace govspons=1 if sponsor==5

*Parliament/ National assembly
replace govspons=1 if sponsor==6

*Government census/ statistics office
replace govspons=1 if sponsor==7

*National Intelligence/ Secret Service
replace govspons=1 if sponsor==8

*Education or Social Affairs Dept./Minis
replace govspons=1 if sponsor==9

*maxtax or Finance Dept./Ministry
replace govspons=1 if sponsor==10

*Health Dept./Ministry
replace govspons=1 if sponsor==11

*Other government dept./ministry
replace govspons=1 if sponsor==12

*Constitutional Commission
replace govspons=1 if sponsor==13

*Electoral Commission
replace govspons=1 if sponsor==14

*National Planning Commission
replace govspons=1 if sponsor==15

*Public Utility Company
replace govspons=1 if sponsor==16

gen incumbentvote=0
replace incumbentvote=. if q99==.
replace incumbentvote=. if q99==-1
replace incumbentvote=. if q99==9999
replace incumbentvote=. if q99==9998
replace incumbentvote=. if q99==9997
replace incumbentvote=. if q99==9996
replace incumbentvote=1 if q99==1420 & country_alph==1
replace incumbentvote=1 if q99==100 & country_alpha==2
replace incumbentvote=1 if q99==141 & country_alpha==3
replace incumbentvote=1 if q99==181 & country_alpha==4
replace incumbentvote=1 if q99==1180 & country_alpha==5
replace incumbentvote=1 if q99==1220 & country_alpha==6
replace incumbentvote=1 if q99==221 & country_alph==7
replace incumbentvote=1 if q99==1261 & country_alpha==8
replace incumbentvote=1 if q99==1460 & country_alpha==9
replace incumbentvote=1 if q99==261 & country_alpha==11
replace incumbentvote=1 if q99==1300 & country_alpha==12
replace incumbentvote=1 if q99==302 & country_alpha==13
replace incumbentvote=1 if q99==342 & country_alph==14
replace incumbentvote=1 if q99==386 & country_alpha==15
replace incumbentvote=1 if q99==437 & country_alpha==16
replace incumbentvote=1 if q99==462 & country_alpha==17
*Military president in Mali
replace incumbentvote=. if country_alpha==18
replace incumbentvote=1 if q99==900 & country_alpha==19
replace incumbentvote=1 if q99==1502 & country_alph==20
replace incumbentvote=1 if q99==540 & country_alpha==21
replace incumbentvote=1 if q99==590 & country_alpha==22
replace incumbentvote=1 if q99==1105 & country_alpha==23
replace incumbentvote=1 if q99==638 & country_alpha==24
replace incumbentvote=1 if q99==663 & country_alpha==25
replace incumbentvote=1 if q99==930 & country_alpha==26
replace incumbentvote=1 if q99==702 & country_alpha==27
replace incumbentvote=1 if q99==1540 & country_alph==28
*Swaziland has a Non-partisan Prime miniser
replace incumbentvote=. if country_alph==29 
replace incumbentvote=1 if q99==740 & country_alph==30
replace incumbentvote=1 if q99==1140 & country_alpha==31
replace incumbentvote=1 if q99==1582 & country_alph==32
replace incumbentvote=1 if q99==780 & country_alpha==33
replace incumbentvote=1 if q99==826 & country_alpha==34
replace incumbentvote=1 if q99==861 & country_alpha==35

*random effects

rename q112 enum_code


***independent variables

gen urban=urbrur
replace urban=0 if urbrur==2
replace urban=0 if urbrur==3
tab urbrur urban
drop urbrur

gen rural=urban
replace rural=1 if urban==0
replace rural=0 if urban==1

rename ea_svc_a electricity
recode electricity 9=.
rename ea_svc_b water
recode electricity 9=.
rename  ea_svc_c sewage
recode sewage 9=.
rename  ea_fac_b nearschool
recode nearschool 9=.
rename  ea_fac_c nearpolice
recode nearpolice 9=.
rename  ea_fac_d nearhealth
recode nearhealth 9=.
rename ea_road paved

egen site = group(region electricity water sewage region nearschool nearpolice nearhealth paved)

rename q1 age
recode age 998=. 999=. -1=.

rename q3a countryecon 
label var countryecon "Q4a present economic condition of the country"
rename q3b personecon
label var personecon "Q4b own living condition"
recode countryecon -1=. 9=.
recode personecon -1=. 9=.

rename q5a pastcountryecon 
label var pastcountryecon " Q6a economic condition of the country compared to 12 months ago"
rename q5b pastpersonecon
label var pastpersonecon "Q6b own living condition compared to 12 months ago"

recode pastcountryecon -1=. 9=.
recode pastpersonecon -1=. 9=.

rename q13a radionews
recode radionews -1=. 9=. 998=.

rename q101 gender
gen female=gender
recode female 2=1 1=0

rename q97 education
recode education -1=. 9=.

rename q96 employment
recode employment -1=. 9=.


*Making these all dummy variables (in between category is always 0)
gen survinterest=q110b 
label var survinterest "was the respondent intereted in the survey"
replace survinterest=. if q110b==-1
tab q110b survinterest
drop q110b

gen survcoop= q110c 
label var survcoop "How cooperative was the respondent"
replace survcoop=. if q110c==-1
tab q110c survcoop
drop q110c

gen survpatient= q110d
label var survpatient "how patient was the respondent with the survey"
replace survpatient=. if q110d==-1
tab q110d survpatient
drop q110d

gen survsus=q110e
label var survsus "was the respondent suspicious of the interviewer"
replace survsus=. if q110e==-1
tab q110e survsus
drop q110e

gen survhonest=q110f
label var survhonest "Was the respondent honest or misleading"
replace survhonest=. if q110f==-1
tab q110f survhonest
drop q110f

rename q108 difficult
replace difficult=. if difficult==-1

gen others=q106
label var others "Were there other people present during the interview?"
replace others=. if q106==-1
replace others=0 if q106==1
replace others=0 if q106==2
replace others=0 if q106==3
replace others=1 if q106==4
replace others=1 if q106==5

gen privatetap=q95a
replace privatetap=. if q95a==-1
replace privatetap=. if q95a==9
replace privatetap=1 if privatetap==2
replace privatetap=0 if privatetap==3
tab q95a privatetap


gen incometaxes=q73d
replace incometaxes=. if q73d==-1
replace incometaxes=. if q73d==7
replace incometaxes=. if q73d==9

gen employed=employment
replace employed=0 if employment==1
replace employed=1 if employment==2
replace employed=1 if employment==3
tab employment employed


gen evernewspaper=q13c
replace evernewspaper=1 if q13c>0
replace evernewspaper=. if q13c==-1
replace evernewspaper=. if q13c==998
replace evernewspaper=. if q13c==9
tab q13c evernewspaper

gen dailycomputer=q91a
replace dailycomputer=0 if q91a!=4
replace dailycomputer=1 if q91a==4
replace dailycomputer=. if q91a==-1
replace dailycomputer=. if q91a==9
tab q91a dailycomputer




*coding coethnicity

rename q84 ethnic


gen coethnic=0 
replace coethnic=. if country_alph==1
replace coethnic=1 if ethnic==102 & country_alpha==2
replace coethnic=1 if ethnic==142 & country_alpha==3
replace coethnic=1 if ethnic==180 & country_alpha==4
replace coethnic=1 if ethnic==1180 & country_alpha==5
replace coethnic=1 if ethnic==1220 & country_alpha==6
replace coethnic=. if country_alph==7
replace coethnic=1 if ethnic==1262 & country_alpha==8
replace coethnic=1 if ethnic==1264 & country_alpha==8
replace coethnic=. if country_alph==9
replace coethnic=1 if ethnic==3 & country_alpha==11
replace coethnic=1 if ethnic==20 & country_alpha==12
replace coethnic=1 if ethnic==300 & country_alpha==13
replace coethnic=1 if ethnic==306 & country_alpha==13
replace coethnic=1 if ethnic==301 & country_alpha==13
replace coethnic=. if country_alph==14
replace coethnic=1 if ethnic==392 & country_alpha==15
replace coethnic=1 if ethnic==432 & country_alpha==16
replace coethnic=1 if ethnic==17 & country_alpha==17
replace coethnic=1 if ethnic==467 & country_alpha==17
replace coethnic=1 if ethnic==26 & country_alpha==17
replace coethnic=1 if ethnic==464 & country_alpha==17
replace coethnic=1 if ethnic==20 & country_alpha==18
replace coethnic=1 if ethnic==903 & country_alpha==19
replace coethnic=. if country_alph==20
replace coethnic=1 if ethnic==544 & country_alpha==21
replace coethnic=1 if ethnic==580 & country_alpha==22
replace coethnic=1 if ethnic==11 & country_alpha==23
replace coethnic=1 if ethnic==631 & country_alpha==24
replace coethnic=1 if ethnic==661 & country_alpha==25
replace coethnic=1 if ethnic==942 & country_alpha==26
replace coethnic=1 if ethnic==710 & country_alpha==27
replace coethnic=. if country_alph==28
replace coethnic=. if country_alph==29
replace coethnic=. if country_alph==30
replace coethnic=1 if ethnic==1142 & country_alpha==31
replace coethnic=. if country_alph==32
replace coethnic=1 if ethnic==781 & country_alpha==33
replace coethnic=1 if ethnic==820 & country_alpha==34
replace coethnic=1 if ethnic==861 & country_alpha==35

label var coethnic "Co-ethnic dummy based on the EPR dataset"




replace coethnic=. if ethnic==.
replace coethnic=. if ethnic==9990
replace coethnic=. if ethnic==9997
replace coethnic=. if ethnic==9998
replace coethnic=. if ethnic==9999



*GDP per cap ppp variables 
*from world bank

gen GDPpc=0 
replace GDPpc=13026.19166 if country_alph==1
replace GDPpc=1761.574331 if country_alph==2
replace GDPpc=13634.26789 if country_alph==3
replace GDPpc=1470.435184 if country_alph==4
replace GDPpc=712.6704834 if country_alph==5
replace GDPpc=2614.495561 if country_alph==6
replace GDPpc=6147.974534 if country_alph==7
replace GDPpc=2546.906812 if country_alph==8
replace GDPpc=10071.20526 if country_alph==9
replace GDPpc=3430.857389 if country_alph==11
replace GDPpc=1183.855846 if country_alph==12
replace GDPpc=2622.730169 if country_alph==13
replace GDPpc=2297.389548 if country_alph==14
replace GDPpc=732.6330069 if country_alph==15
replace GDPpc=1371.648575 if country_alph==16
replace GDPpc=758.5815996 if country_alph==17
replace GDPpc=1528.400301 if country_alph==18
replace GDPpc=16179.29153 if country_alph==19
replace GDPpc=6746.90     if country_alph==20
replace GDPpc=951.8253639 if country_alph==21
replace GDPpc=8625.717922 if country_alph==22
replace GDPpc=807.1930209 if country_alph==23
replace GDPpc=5230.598854 if country_alph==24
replace GDPpc=2159.022888 if country_alph==25
replace GDPpc=1374.579145 if country_alph==26
replace GDPpc=12290.89436 if country_alph==27
replace GDPpc=3478.252239 if country_alph==28
replace GDPpc=7620.196615 if country_alph==29
replace GDPpc=2206.910779 if country_alph==30
replace GDPpc=1255.087825 if country_alph==31
replace GDPpc=10218.57874 if country_alph==32
replace GDPpc=1648.531066 if country_alph==33
replace GDPpc=3381.356194 if country_alph==34
replace GDPpc=1523.621784 if country_alph==35
replace GDPpc=GDPpc/100



*Coding in the highest marginal maxtax rate

gen maxtax=0 
replace maxtax=.35 if country_alph==1
replace maxtax=.45 if country_alph==2
replace maxtax=.25 if country_alph==3
replace maxtax=.25 if country_alph==4
replace maxtax=.3 if country_alph==5
replace maxtax=.35 if country_alph==6
replace maxtax=.26 if country_alph==7
replace maxtax=.1 if country_alph==8
replace maxtax=.25 if country_alph==9
replace maxtax=.25 if country_alph==11
replace maxtax=.4 if country_alph==12
replace maxtax=.3 if country_alph==13
replace maxtax=.3 if country_alph==14
replace maxtax=.25 if country_alph==15
replace maxtax=.2 if country_alph==16
replace maxtax=.3 if country_alph==17
replace maxtax=.3 if country_alph==18
replace maxtax=.15 if country_alph==19
replace maxtax=.38 if country_alph==20
replace maxtax=.32 if country_alph==21
replace maxtax=.37 if country_alph==22
*replace maxtax= if country_alph==23 MISSING FOR NIGER
replace maxtax=.24 if country_alph==24
replace maxtax=.4 if country_alph==25
replace maxtax=.3 if country_alph==26
replace maxtax=.4 if country_alph==27
replace maxtax=.15 if country_alph==28
replace maxtax=.33 if country_alph==29
replace maxtax=.3 if country_alph==30
*replace maxtax= if country_alph==31 MISSING FOR TOGO
replace maxtax=.35 if country_alph==32
replace maxtax=.4 if country_alph==33
replace maxtax=.35 if country_alph==34
replace maxtax=.5 if country_alph==35
replace maxtax=. if maxtax==0

gen taxpay=q75c
recode taxpay .a=. -1=. 7=. 9=.

gen evasiontax=maxtax*taxpay

rename q8a foodlack
rename q8b waterlack
rename q8c medicallack
rename q8d fuellack
rename q8e cashlack

replace foodlack=. if foodlack==-1
replace foodlack=. if foodlack==9
replace waterlack=. if waterlack==-1
replace waterlack=. if waterlack==9
replace medicallack=. if medicallack==-1
replace medicallack=. if medicallack==9
replace fuellack=. if fuellack==-1
replace fuellack=. if fuellack==9
replace cashlack=. if cashlack==-1
replace cashlack=. if cashlack==9


factor foodlack waterlack cashlack medicallack fuellack
rotate
predict flivedpov
gen fwealth=0-flivedpov

gen askedtaxes=1
replace askedtaxes = 0 if q75c==.a

*interactions

gen sponsprivate=privatetap*govspons

gen evasiontaxspons= evasiontax*govspons

gen wealthspons=fwealth*govspons

gen pastspons=pastperson*govspons

gen pasttax = evasiontax*pastperson










